import React, { useState, useRef, useEffect, useMemo } from "react";
import {
    Edit,
    SimpleForm,
    FormDataConsumer,
    useTranslate,
    TextInput,
    NumberInput,
    BooleanInput,
    DateInput,
    SelectInput,
    ReferenceInput,
    ReferenceArrayInput,
    AutocompleteInput,
    SaveButton,
    Toolbar,
    Labeled,
    NumberField,
    required,
    useRecordContext,
    DeleteButton,
} from 'react-admin';
import { useWatch, useFormContext } from "react-hook-form";
import { Stack, Grid, Box, Typography } from '@mui/material';
import * as Common from '@/utils/common';
import { EDIT_MODE, REFERENCE_INPUT_PAGESIZE } from '@/config/setting';
import EditBaseAside from "../../components/EditBaseAside";
import CustomerTopToolBar from "../../components/EditTopToolBar";
import MemoInput from "../../components/MemoInput";
import StatusSelectInput from "../../components/StatusSelectInput";
import PurchaseItemList from "./PurchaseItemList";

const FormToolbar = () => {
    const { getValues } = useFormContext();
    return (
        <Toolbar sx={{ justifyContent: 'end' }}>
            <SaveButton />
            <DeleteButton mutationMode="optimistic" />
        </Toolbar>
    )
}

const PurchaseEdit = () => {
    const translate = useTranslate();

    return (
        <>
            <Edit
                redirect="list"
                mutationMode={EDIT_MODE}
                actions={<CustomerTopToolBar />}
                aside={<EditBaseAside />}
            >
                <SimpleForm
                    shouldUnregister
                    warnWhenUnsavedChanges
                    toolbar={<FormToolbar />}
                    mode="onTouched"
                    defaultValues={{}}
                // validate={(values) => { }}
                >
                    <Grid container width={{ xs: '100%', xl: '80%' }} rowSpacing={3} columnSpacing={3}>
                        <Grid item xs={18} md={10}>
                            <Typography variant="h6" gutterBottom>
                                {translate('common.edit.title.main')}
                            </Typography>
                            {/* <Stack direction='row' gap={2}>
                            <TextInput
                                label="table.field.purchase.code"
                                source="code"
                                parse={v => v}
                                autoFocus
                            />
                        </Stack> */}
                            <Stack direction='row' gap={2}>
                                <TextInput
                                    label="table.field.purchase.type"
                                    source="type$"
                                    parse={v => v}
                                    validate={required()}
                                />
                                <TextInput
                                    label="table.field.purchase.source"
                                    source="source"
                                    parse={v => v}
                                    validate={required()}
                                />
                                <DateInput
                                    label="table.field.purchase.preArr"
                                    source="preArr"
                                />
                                <NumberInput
                                    label="table.field.purchase.anfme"
                                    source="anfme"
                                    validate={required()}
                                />
                            </Stack>
                            <Stack direction='row' gap={2}>
                                <NumberInput
                                    label="table.field.purchase.qty"
                                    source="qty"
                                    validate={required()}
                                />
                                <NumberInput
                                    label="table.field.purchase.workQty"
                                    source="workQty"
                                    validate={required()}
                                />
                                <TextInput
                                    label="table.field.purchase.channel"
                                    source="channel"
                                    parse={v => v}
                                />
                                <TextInput
                                    label="table.field.purchase.platCode"
                                    source="platCode"
                                    parse={v => v}
                                />
                            </Stack>
                            <Stack direction='row' gap={2}>
                            <DateInput
                                    label="table.field.purchase.startTime"
                                    source="startTime"
                                />
                                <DateInput
                                    label="table.field.purchase.endTime"
                                    source="endTime"
                                />
                                <TextInput
                                    label="table.field.purchase.project"
                                    source="project"
                                    parse={v => v}
                                />
                            </Stack>
                        </Grid>
                        <Grid item xs={6} md={2}>
                            <Typography variant="h6" gutterBottom>
                                {translate('common.edit.title.common')}
                            </Typography>
                            <StatusSelectInput />
                            <Box mt="2em" />
                            <MemoInput />
                        </Grid>
                    </Grid>
                </SimpleForm>
            </Edit >
            <PurchaseItemList />                            
        </>
    )
}

export default PurchaseEdit;
